@@ -1,13 +1,13 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "org-web-track" "0.1.1"
+(define-package "org-web-track" "20250610.1142"
   "Web data tracking framework in Org Mode."
   '((emacs   "29.1")
     (request "0.3.0")
     (enlive  "0.0.1")
     (gnuplot "0.8.1"))
   :url "https://github.com/p-snow/org-web-track"
-  :commit "2cf9367ef6f8800fa058a8ca30cbb6f2e75fe4de"
-  :revdesc "2cf9367ef6f8"
+  :commit "c32eebcd1794f618b723cbaadae125cc98781121"
+  :revdesc "c32eebcd1794"
   :keywords '("org" "agenda" "web" "hypermedia")
   :authors '(("p-snow" . "public@p-snow.org"))
   :maintainers '(("p-snow" . "public@p-snow.org")))
